@@ -1,31 +1,35 @@
 import logging
 import os
 import platform
-from .. import TwilioException
+from ..exceptions import TwilioException
 from .. import __version__ as LIBRARY_VERSION
-from .resources import make_request
-from .resources import Accounts
-from .resources import Applications
-from .resources import AuthorizedConnectApps
-from .resources import CallerIds
-from .resources import Calls
-from .resources import Conferences
-from .resources import ConnectApps
-from .resources import Connection
-from .resources import MediaList
-from .resources import Members
-from .resources import Messages
-from .resources import Notifications
-from .resources import Participants
-from .resources import PhoneNumbers
-from .resources import Queues
-from .resources import Recordings
-from .resources import Sandboxes
-from .resources import Sip
-from .resources import Sms
-from .resources import Transcriptions
-from .resources import UNSET_TIMEOUT
-from .resources import Usage
+from .resources import (
+    make_request,
+    Accounts,
+    Applications,
+    AuthorizedConnectApps,
+    CallerIds,
+    Calls,
+    Conferences,
+    ConnectApps,
+    Connection,
+    MediaList,
+    Members,
+    Messages,
+    Notifications,
+    Participants,
+    PhoneNumbers,
+    Queues,
+    Recordings,
+    Sandboxes,
+    Sip,
+    Sms,
+    Transcriptions,
+    UNSET_TIMEOUT,
+    Usage,
+    CallFeedbackFactory,
+    CallFeedback,
+)
 
 
 def find_credentials(environ=None):
@@ -133,6 +137,20 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         base_uri = "%s/Queues/%s" % (self.account_uri, queue_sid)
         return Members(base_uri, self.auth, self.timeout)
 
+    def feedback(self, call_sid):
+        """
+        Return a :class:`CallFeedback <twilio.rest.resources.CallFeedback>`
+        instance for the :class:`Call <twilio.rest.resources.calls.Call>`
+        with the given call_sid
+        """
+        base_uri = "%s/Calls/%s/Feedback" % (self.account_uri, call_sid)
+        call_feedback_list = CallFeedbackFactory(
+            base_uri,
+            self.auth,
+            self.timeout
+        )
+        return CallFeedback(call_feedback_list)
+
     def request(self, path, method=None, vars=None):
         """sends a request and gets a response from the Twilio REST API
 
