@@ -1,4 +1,5 @@
-from ... import TwilioException, TwilioRestException
+from ...exceptions import TwilioException
+from ..exceptions import TwilioRestException
 
 from .imports import (
     parse_qs, json, httplib2
@@ -24,6 +25,10 @@ from .connect_apps import (
 )
 from .calls import Call, Calls
 from .caller_ids import CallerIds, CallerId
+from .call_feedback import (
+    CallFeedbackFactory, CallFeedback, CallFeedbackSummary,
+    CallFeedbackSummaryInstance
+)
 from .connection import Connection
 from .sandboxes import Sandbox, Sandboxes
 from .sms_messages import (
