@@ -1,6 +1,10 @@
 from .notifications import Notifications
 from .recordings import Recordings
-from .util import normalize_dates, parse_date
+from twilio.rest.resources.call_feedback import (
+    CallFeedbackFactory,
+    CallFeedbackSummary,
+)
+from .util import normalize_dates, parse_date, transform_params
 from . import InstanceResource, ListResource
 
 
@@ -19,6 +23,7 @@ class Call(InstanceResource):
     subresources = [
         Notifications,
         Recordings,
+        CallFeedbackFactory,
     ]
 
     def hangup(self):
@@ -52,6 +57,10 @@ class Calls(ListResource):
     name = "Calls"
     instance = Call
 
+    def __init__(self, *args, **kwargs):
+        super(Calls, self).__init__(*args, **kwargs)
+        self.summary = CallFeedbackSummary(self, *args, **kwargs)
+
     @normalize_dates
     def list(self, from_=None, ended_after=None,
              ended_before=None, ended=None, started_before=None,
@@ -144,3 +153,19 @@ class Calls(ListResource):
         :returns: Updated :class:`Call` resource
         """
         return self.update(sid, url=url, method=method)
+
+    def feedback(self, sid, quality_score, issue=None):
+        """ Create feedback for the given call.
+
+        :param sid: A Call Sid for a specific call
+        :param quality_score: The quality of the call
+        :param issue: A list of issues experienced during the call
+        :returns: A :class:`CallFeedback` object
+        """
+        uri = "%s/%s" % (self.uri, sid)
+        call_feedback_factory = CallFeedbackFactory(
+            uri, self.auth, self.timeout
+        )
+        return call_feedback_factory.create(
+            quality_score=quality_score, issue=issue
+        )
