@@ -1,9 +1,12 @@
 import re
 
-from twilio import TwilioException
-from twilio.rest.resources.util import change_dict_key, transform_params
-from twilio.rest.resources.util import UNSET_TIMEOUT
-from twilio.rest.resources import InstanceResource, ListResource
+from .. import TwilioException
+from .util import change_dict_key, transform_params
+from .util import UNSET_TIMEOUT
+from . import InstanceResource, ListResource
+
+
+TYPES = {"local": "Local", "tollfree": "TollFree", "mobile": "Mobile"}
 
 
 class AvailablePhoneNumber(InstanceResource):
@@ -63,8 +66,6 @@ class AvailablePhoneNumbers(ListResource):
     key = "available_phone_numbers"
     instance = AvailablePhoneNumber
 
-    types = {"local": "Local", "tollfree": "TollFree"}
-
     def __init__(self, base_uri, auth, timeout, phone_numbers):
         super(AvailablePhoneNumbers, self).__init__(base_uri, auth, timeout)
         self.phone_numbers = phone_numbers
@@ -83,7 +84,7 @@ class AvailablePhoneNumbers(ListResource):
         kwargs["in_rate_center"] = kwargs.get("in_rate_center", rate_center)
         params = transform_params(kwargs)
 
-        uri = "%s/%s/%s" % (self.uri, country, self.types[type])
+        uri = "%s/%s/%s" % (self.uri, country, TYPES[type])
         resp, page = self.request("GET", uri, params=params)
 
         return [self.load_instance(i) for i in page[self.key]]
@@ -258,14 +259,24 @@ class PhoneNumbers(ListResource):
         """
         return self.delete_instance(sid)
 
-    def list(self, **kwargs):
+    def list(self, type=None, **kwargs):
         """
         :param phone_number: Show phone numbers that match this pattern.
         :param friendly_name: Show phone numbers with this friendly name
+        :param type: Filter numbers by type. Available types are
+            'local', 'mobile', or 'tollfree'
 
         You can specify partial numbers and use '*' as a wildcard.
         """
-        return self.get_instances(kwargs)
+
+        uri = self.uri
+        if type:
+            uri = "%s/%s" % (self.uri, TYPES[type])
+
+        params = transform_params(kwargs)
+        resp, page = self.request("GET", uri, params=params)
+
+        return [self.load_instance(i) for i in page[self.key]]
 
     def purchase(self, status_callback_url=None, **kwargs):
         """
@@ -283,7 +294,15 @@ class PhoneNumbers(ListResource):
         if 'phone_number' not in kwargs and 'area_code' not in kwargs:
             raise TypeError("phone_number or area_code is required")
 
-        return self.create_instance(kwargs)
+        number_type = kwargs.pop('type', False)
+        uri = self.uri
+        if number_type:
+            uri = "%s/%s" % (self.uri, TYPES[number_type])
+
+        params = transform_params(kwargs)
+        resp, instance = self.request('POST', uri, data=params)
+
+        return self.load_instance(instance)
 
     def search(self, **kwargs):
         """
