@@ -1,4 +1,4 @@
-from twilio.rest.resources import InstanceResource, ListResource
+from . import InstanceResource, ListResource
 
 
 class Transcription(InstanceResource):
@@ -7,7 +7,7 @@ class Transcription(InstanceResource):
         """
         Delete this transcription
         """
-        return self.parent.delete(self.sid)
+        return self.parent.delete(self.name)
 
 
 class Transcriptions(ListResource):
